Module: Axiom::Function::Predicate::LessThan::Methods
- Included in:
- Attribute::Comparable
- Defined in:
- lib/axiom/function/predicate/less_than.rb
Instance Method Summary collapse
-
#lt(other) ⇒ LessThan
Compare the left to see if it is less than the right.
Instance Method Details
#lt(other) ⇒ LessThan
Compare the left to see if it is less than the right
59 60 61 |
# File 'lib/axiom/function/predicate/less_than.rb', line 59 def lt(other) LessThan.new(self, other) end |